@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.099_05';
+our $VERSION = '0.100_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Fri Jul 13 14:43:18 2018 GMT
+# on Wed Jul 18 13:51:53 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1761,7 +1761,7 @@ __PACKAGE__->status( add => 25346, iridium => 'D', 'Iridium 75', 'Decayed 2018-0
 __PACKAGE__->status( add => 25431, iridium => 'D', 'Iridium 3', 'Decayed 2018-02-08' );
 __PACKAGE__->status( add => 25432, iridium => 'S', 'Iridium 76', '' );
 __PACKAGE__->status( add => 25467, iridium => '-', 'Iridium 82', 'Tumbling' );
-__PACKAGE__->status( add => 25468, iridium => '-', 'Iridium 81', 'Tumbling' );
+__PACKAGE__->status( add => 25468, iridium => 'D', 'Iridium 81', 'Decayed 2018-07-17' );
 __PACKAGE__->status( add => 25469, iridium => 'S', 'Iridium 80', '' );
 __PACKAGE__->status( add => 25470, iridium => 'D', 'Iridium 79', 'Decayed 2000-11-29' );
 __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-09-22' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'S', 'Iridium 98', '' );
 # Summary:
 # Operational [+]: 17
 #       Spare [S]: 17
-#    Tumbling [-]: 38
-#     Decayed [D]: 25
+#    Tumbling [-]: 37
+#     Decayed [D]: 26
 
 1;
 
